|
From: <sv...@va...> - 2014-07-18 00:04:14
|
Author: philippe
Date: Fri Jul 18 00:03:58 2014
New Revision: 14175
Log:
Patch adding (or showing the proper/not confusing) helgrind thread nr for block
and stack address description.
* A race condition on an allocated block shows the stacktrace, but
does not show the thread # that allocated the block.
This patch adds the output of the thread # that allocated the block.
* The patch also fixes the confusion that might appear between
the core threadid and the helgrind thread nr in Stack address description:
A printed stack addrinfo was containing a thread id, while all other helgrind
messages are using (supposed to use) an 'helgrind thread #' which
is used in the thread announcement.
Basically, the idea is to let a tool set a "tool specific thread nr'
in an addrinfo.
The pretty printing of the addrinfo is then by preference showing this
thread nr (if it was set, i.e. different of 0).
Currently, only helgrind uses this addrinfo tnr.
Note: in xml mode, the output is matching the protocol description.
I.e., GUI should not be impacted by this change, if they properly implement
the xml protocol.
* Also, make the output produced by m_addrinfo consistent:
The message 'block was alloc'd at' is changed to be like all other
output : one character indent, and starting with an uppercase
Modified:
trunk/NEWS
trunk/coregrind/m_addrinfo.c
trunk/gdbserver_tests/hginfo.stderrB.exp
trunk/helgrind/hg_addrdescr.c
trunk/helgrind/hg_addrdescr.h
trunk/helgrind/hg_errors.c
trunk/helgrind/hg_main.c
trunk/helgrind/tests/pth_barrier1.stderr.exp
trunk/helgrind/tests/pth_barrier2.stderr.exp
trunk/helgrind/tests/pth_barrier3.stderr.exp
trunk/helgrind/tests/tc19_shadowmem.stderr.exp
trunk/include/pub_tool_addrinfo.h
trunk/memcheck/mc_errors.c
trunk/memcheck/tests/malloc1_ks_alloc.stderr.exp
trunk/memcheck/tests/malloc1_ks_alloc_and_free.stderr.exp
Modified: trunk/NEWS
==============================================================================
--- trunk/NEWS (original)
+++ trunk/NEWS Fri Jul 18 00:03:58 2014
@@ -17,6 +17,8 @@
* Helgrind:
- Helgrind GDB server monitor command 'info locks' giving
the list of locks, their location, and their status.
+ - Race condition error message with allocated blocks also show
+ the thread nr that allocated the racy block.
- Helgrind now understands the Ada task termination rules
and creates a 'H-B relationship' between a terminated task and
its master. This avoids some false positive and avoids big
Modified: trunk/coregrind/m_addrinfo.c
==============================================================================
--- trunk/coregrind/m_addrinfo.c (original)
+++ trunk/coregrind/m_addrinfo.c Fri Jul 18 00:03:58 2014
@@ -105,7 +105,8 @@
UInt f;
ai->tag = Addr_Stack;
- ai->Addr.Stack.tid = tid;
+ VG_(initThreadInfo)(&ai->Addr.Stack.tinfo);
+ ai->Addr.Stack.tinfo.tid = tid;
ai->Addr.Stack.IP = 0;
ai->Addr.Stack.frameNo = -1;
/* It is on thread tid stack. Build a stacktrace, and
@@ -153,6 +154,7 @@
ai->Addr.Block.block_szB = aai.block_szB;
ai->Addr.Block.rwoffset = aai.rwoffset;
ai->Addr.Block.allocated_at = VG_(null_ExeContext)();
+ VG_(initThreadInfo) (&ai->Addr.Block.alloc_tinfo);
ai->Addr.Block.freed_at = VG_(null_ExeContext)();
return;
}
@@ -177,6 +179,12 @@
return;
}
+void VG_(initThreadInfo) (ThreadInfo *tinfo)
+{
+ tinfo->tid = 0;
+ tinfo->tnr = 0;
+}
+
void VG_(clear_addrinfo) ( AddrInfo* ai)
{
switch (ai->tag) {
@@ -230,6 +238,22 @@
}
}
+static const HChar* opt_tnr_prefix (ThreadInfo tinfo)
+{
+ if (tinfo.tnr != 0)
+ return "#";
+ else
+ return "";
+}
+
+static UInt tnr_else_tid (ThreadInfo tinfo)
+{
+ if (tinfo.tnr != 0)
+ return tinfo.tnr;
+ else
+ return tinfo.tid;
+}
+
static void pp_addrinfo_WRK ( Addr a, AddrInfo* ai, Bool mc, Bool maybe_gcc )
{
const HChar* xpre = VG_(clo_xml) ? " <auxwhat>" : " ";
@@ -254,8 +278,11 @@
break;
case Addr_Stack:
- VG_(emit)( "%sAddress 0x%llx is on thread %d's stack%s\n",
- xpre, (ULong)a, ai->Addr.Stack.tid, xpost );
+ VG_(emit)( "%sAddress 0x%llx is on thread %s%d's stack%s\n",
+ xpre, (ULong)a,
+ opt_tnr_prefix (ai->Addr.Stack.tinfo),
+ tnr_else_tid (ai->Addr.Stack.tinfo),
+ xpost );
if (ai->Addr.Stack.frameNo != -1 && ai->Addr.Stack.IP != 0) {
#define FLEN 256
HChar fn[FLEN];
@@ -344,7 +371,7 @@
VG_(pp_ExeContext)(ai->Addr.Block.freed_at);
if (ai->Addr.Block.allocated_at != VG_(null_ExeContext)()) {
VG_(emit)(
- "%s block was alloc'd at%s\n",
+ "%sBlock was alloc'd at%s\n",
xpre,
xpost
);
@@ -364,7 +391,14 @@
tl_assert (ai->Addr.Block.allocated_at == VG_(null_ExeContext)());
tl_assert (ai->Addr.Block.freed_at == VG_(null_ExeContext)());
}
-
+ if (ai->Addr.Block.alloc_tinfo.tnr || ai->Addr.Block.alloc_tinfo.tid)
+ VG_(emit)(
+ "%sBlock was alloc'd by thread %s%d%s\n",
+ xpre,
+ opt_tnr_prefix (ai->Addr.Block.alloc_tinfo),
+ tnr_else_tid (ai->Addr.Block.alloc_tinfo),
+ xpost
+ );
break;
}
Modified: trunk/gdbserver_tests/hginfo.stderrB.exp
==============================================================================
--- trunk/gdbserver_tests/hginfo.stderrB.exp (original)
+++ trunk/gdbserver_tests/hginfo.stderrB.exp Fri Jul 18 00:03:58 2014
@@ -10,6 +10,7 @@
by 0x........: th (hg01_all_ok.c:22)
by 0x........: mythread_wrapper (hg_intercepts.c:...)
...
+ Block was alloc'd by thread #x
Lock ga 0x........ {
Address 0x........ is 0 bytes inside data symbol "mx"
kind mbRec
Modified: trunk/helgrind/hg_addrdescr.c
==============================================================================
--- trunk/helgrind/hg_addrdescr.h (original)
+++ trunk/helgrind/hg_addrdescr.h Fri Jul 18 00:03:58 2014
@@ -59,6 +59,7 @@
considered to contain the searched-for address if they equal that
address. */
Bool HG_(mm_find_containing_block)( /*OUT*/ExeContext** where,
+ /*OUT*/UInt* tnr,
/*OUT*/Addr* payload,
/*OUT*/SizeT* szB,
Addr data_addr );
Modified: trunk/helgrind/hg_errors.c
==============================================================================
--- trunk/helgrind/hg_errors.c (original)
+++ trunk/helgrind/hg_errors.c Fri Jul 18 00:03:58 2014
@@ -865,6 +865,17 @@
announce_one_thread( xe->XE.Race.h2_ct );
if (xe->XE.Race.h1_ct)
announce_one_thread( xe->XE.Race.h1_ct );
+ if (xe->XE.Race.data_addrinfo.Addr.Block.alloc_tinfo.tnr) {
+ Thread* thr = get_admin_threads();
+ while (thr) {
+ if (thr->errmsg_index
+ == xe->XE.Race.data_addrinfo.Addr.Block.alloc_tinfo.tnr) {
+ announce_one_thread (thr);
+ break;
+ }
+ thr = thr->admin;
+ }
+ }
break;
default:
tl_assert(0);
Modified: trunk/helgrind/hg_main.c
==============================================================================
--- trunk/helgrind/hg_main.c (original)
+++ trunk/helgrind/hg_main.c Fri Jul 18 00:03:58 2014
@@ -4213,6 +4213,7 @@
}
Bool HG_(mm_find_containing_block)( /*OUT*/ExeContext** where,
+ /*OUT*/UInt* tnr,
/*OUT*/Addr* payload,
/*OUT*/SizeT* szB,
Addr data_addr )
@@ -4249,6 +4250,7 @@
tl_assert(mm);
tl_assert(addr_is_in_MM_Chunk(mm, data_addr));
if (where) *where = mm->where;
+ if (tnr) *tnr = mm->thr->errmsg_index;
if (payload) *payload = mm->payload;
if (szB) *szB = mm->szB;
return True;
@@ -4868,7 +4870,8 @@
SizeT pszB = 0;
if (0) VG_(printf)("VG_USERREQ__HG_CLEAN_MEMORY_HEAPBLOCK(%#lx)\n",
args[1]);
- if (HG_(mm_find_containing_block)(NULL, &payload, &pszB, args[1])) {
+ if (HG_(mm_find_containing_block)(NULL, NULL,
+ &payload, &pszB, args[1])) {
if (pszB > 0) {
evh__die_mem(payload, pszB);
evh__new_mem(payload, pszB);
Modified: trunk/helgrind/tests/pth_barrier1.stderr.exp
==============================================================================
--- trunk/helgrind/tests/pth_barrier1.stderr.exp (original)
+++ trunk/helgrind/tests/pth_barrier1.stderr.exp Fri Jul 18 00:03:58 2014
@@ -14,6 +14,10 @@
by 0x........: barriers_and_races (pth_barrier.c:92)
by 0x........: main (pth_barrier.c:122)
+---Thread-Announcement------------------------------------------
+
+Thread #x is the program's root thread
+
----------------------------------------------------------------
Possible data race during write of size 1 at 0x........ by thread #x
@@ -31,4 +35,5 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
Modified: trunk/helgrind/tests/pth_barrier2.stderr.exp
==============================================================================
--- trunk/helgrind/tests/pth_barrier2.stderr.exp (original)
+++ trunk/helgrind/tests/pth_barrier2.stderr.exp Fri Jul 18 00:03:58 2014
@@ -14,6 +14,10 @@
by 0x........: barriers_and_races (pth_barrier.c:92)
by 0x........: main (pth_barrier.c:122)
+---Thread-Announcement------------------------------------------
+
+Thread #x is the program's root thread
+
----------------------------------------------------------------
Possible data race during write of size 1 at 0x........ by thread #x
@@ -31,6 +35,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -49,6 +54,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -67,6 +73,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -85,6 +92,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -103,6 +111,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -121,6 +130,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -139,6 +149,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -157,6 +168,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -175,6 +187,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -193,6 +206,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -211,6 +225,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -229,6 +244,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -247,6 +263,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -265,6 +282,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -283,6 +301,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -301,6 +320,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -319,6 +339,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -337,6 +358,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -355,6 +377,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -373,6 +396,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -391,6 +415,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -409,6 +434,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -427,6 +453,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -445,6 +472,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -463,6 +491,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -481,6 +510,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -499,6 +529,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -517,6 +548,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -535,6 +567,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -553,6 +586,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -571,6 +605,7 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -589,4 +624,5 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
Modified: trunk/helgrind/tests/pth_barrier3.stderr.exp
==============================================================================
--- trunk/helgrind/tests/pth_barrier3.stderr.exp (original)
+++ trunk/helgrind/tests/pth_barrier3.stderr.exp Fri Jul 18 00:03:58 2014
@@ -14,6 +14,10 @@
by 0x........: barriers_and_races (pth_barrier.c:92)
by 0x........: main (pth_barrier.c:122)
+---Thread-Announcement------------------------------------------
+
+Thread #x is the program's root thread
+
----------------------------------------------------------------
Possible data race during write of size 1 at 0x........ by thread #x
@@ -31,4 +35,5 @@
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: barriers_and_races (pth_barrier.c:76)
by 0x........: main (pth_barrier.c:122)
+ Block was alloc'd by thread #x
Modified: trunk/helgrind/tests/tc19_shadowmem.stderr.exp
==============================================================================
--- trunk/helgrind/tests/tc19_shadowmem.stderr.exp (original)
+++ trunk/helgrind/tests/tc19_shadowmem.stderr.exp Fri Jul 18 00:03:58 2014
@@ -19,6 +19,10 @@
by 0x........: pthread_create@* (hg_intercepts.c:...)
by 0x........: main (tc19_shadowmem.c:172)
+---Thread-Announcement------------------------------------------
+
+Thread #x is the program's root thread
+
----------------------------------------------------------------
Possible data race during write of size 1 at 0x........ by thread #x
@@ -37,6 +41,7 @@
Address 0x........ is 0 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 1 ----------
---Thread-Announcement------------------------------------------
@@ -71,6 +76,7 @@
Address 0x........ is 1 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 2 ----------
---Thread-Announcement------------------------------------------
@@ -105,6 +111,7 @@
Address 0x........ is 2 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 3 ----------
---Thread-Announcement------------------------------------------
@@ -139,6 +146,7 @@
Address 0x........ is 3 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 4 ----------
---Thread-Announcement------------------------------------------
@@ -173,6 +181,7 @@
Address 0x........ is 4 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 5 ----------
---Thread-Announcement------------------------------------------
@@ -207,6 +216,7 @@
Address 0x........ is 5 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 6 ----------
---Thread-Announcement------------------------------------------
@@ -241,6 +251,7 @@
Address 0x........ is 6 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 7 ----------
---Thread-Announcement------------------------------------------
@@ -275,6 +286,7 @@
Address 0x........ is 7 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 8 ----------
---Thread-Announcement------------------------------------------
@@ -309,6 +321,7 @@
Address 0x........ is 8 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 9 ----------
---Thread-Announcement------------------------------------------
@@ -343,6 +356,7 @@
Address 0x........ is 9 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 10 ----------
---Thread-Announcement------------------------------------------
@@ -377,6 +391,7 @@
Address 0x........ is 10 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 11 ----------
---Thread-Announcement------------------------------------------
@@ -411,6 +426,7 @@
Address 0x........ is 11 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 12 ----------
---Thread-Announcement------------------------------------------
@@ -445,6 +461,7 @@
Address 0x........ is 12 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 13 ----------
---Thread-Announcement------------------------------------------
@@ -479,6 +496,7 @@
Address 0x........ is 13 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 14 ----------
---Thread-Announcement------------------------------------------
@@ -513,6 +531,7 @@
Address 0x........ is 14 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 15 ----------
---Thread-Announcement------------------------------------------
@@ -547,6 +566,7 @@
Address 0x........ is 15 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 16 ----------
---Thread-Announcement------------------------------------------
@@ -581,6 +601,7 @@
Address 0x........ is 16 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 17 ----------
---Thread-Announcement------------------------------------------
@@ -615,6 +636,7 @@
Address 0x........ is 17 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 18 ----------
---Thread-Announcement------------------------------------------
@@ -649,6 +671,7 @@
Address 0x........ is 18 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 19 ----------
---Thread-Announcement------------------------------------------
@@ -683,6 +706,7 @@
Address 0x........ is 19 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 20 ----------
---Thread-Announcement------------------------------------------
@@ -717,6 +741,7 @@
Address 0x........ is 20 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 21 ----------
---Thread-Announcement------------------------------------------
@@ -751,6 +776,7 @@
Address 0x........ is 21 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 22 ----------
---Thread-Announcement------------------------------------------
@@ -785,6 +811,7 @@
Address 0x........ is 22 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 23 ----------
---Thread-Announcement------------------------------------------
@@ -819,6 +846,7 @@
Address 0x........ is 23 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 24 ----------
---Thread-Announcement------------------------------------------
@@ -853,6 +881,7 @@
Address 0x........ is 24 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 25 ----------
---Thread-Announcement------------------------------------------
@@ -887,6 +916,7 @@
Address 0x........ is 25 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 26 ----------
---Thread-Announcement------------------------------------------
@@ -921,6 +951,7 @@
Address 0x........ is 26 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 27 ----------
---Thread-Announcement------------------------------------------
@@ -955,6 +986,7 @@
Address 0x........ is 27 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 28 ----------
---Thread-Announcement------------------------------------------
@@ -989,6 +1021,7 @@
Address 0x........ is 28 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 29 ----------
---Thread-Announcement------------------------------------------
@@ -1023,6 +1056,7 @@
Address 0x........ is 29 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 30 ----------
---Thread-Announcement------------------------------------------
@@ -1057,6 +1091,7 @@
Address 0x........ is 30 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 31 ----------
---Thread-Announcement------------------------------------------
@@ -1091,6 +1126,7 @@
Address 0x........ is 31 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 32 ----------
---Thread-Announcement------------------------------------------
@@ -1125,6 +1161,7 @@
Address 0x........ is 32 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 33 ----------
---Thread-Announcement------------------------------------------
@@ -1159,6 +1196,7 @@
Address 0x........ is 33 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 34 ----------
---Thread-Announcement------------------------------------------
@@ -1193,6 +1231,7 @@
Address 0x........ is 34 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 35 ----------
---Thread-Announcement------------------------------------------
@@ -1227,6 +1266,7 @@
Address 0x........ is 35 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 36 ----------
---Thread-Announcement------------------------------------------
@@ -1261,6 +1301,7 @@
Address 0x........ is 36 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 37 ----------
---Thread-Announcement------------------------------------------
@@ -1295,6 +1336,7 @@
Address 0x........ is 37 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 38 ----------
---Thread-Announcement------------------------------------------
@@ -1329,6 +1371,7 @@
Address 0x........ is 38 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 39 ----------
---Thread-Announcement------------------------------------------
@@ -1363,6 +1406,7 @@
Address 0x........ is 39 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 40 ----------
---Thread-Announcement------------------------------------------
@@ -1397,6 +1441,7 @@
Address 0x........ is 40 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 41 ----------
---Thread-Announcement------------------------------------------
@@ -1431,6 +1476,7 @@
Address 0x........ is 41 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 42 ----------
---Thread-Announcement------------------------------------------
@@ -1465,6 +1511,7 @@
Address 0x........ is 42 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 43 ----------
---Thread-Announcement------------------------------------------
@@ -1499,6 +1546,7 @@
Address 0x........ is 43 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 44 ----------
---Thread-Announcement------------------------------------------
@@ -1533,6 +1581,7 @@
Address 0x........ is 44 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 45 ----------
---Thread-Announcement------------------------------------------
@@ -1567,6 +1616,7 @@
Address 0x........ is 45 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 46 ----------
---Thread-Announcement------------------------------------------
@@ -1601,6 +1651,7 @@
Address 0x........ is 46 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 47 ----------
---Thread-Announcement------------------------------------------
@@ -1635,6 +1686,7 @@
Address 0x........ is 47 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 48 ----------
---Thread-Announcement------------------------------------------
@@ -1669,6 +1721,7 @@
Address 0x........ is 48 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 49 ----------
---Thread-Announcement------------------------------------------
@@ -1703,6 +1756,7 @@
Address 0x........ is 49 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 50 ----------
---Thread-Announcement------------------------------------------
@@ -1737,6 +1791,7 @@
Address 0x........ is 50 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 51 ----------
---Thread-Announcement------------------------------------------
@@ -1771,6 +1826,7 @@
Address 0x........ is 51 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 52 ----------
---Thread-Announcement------------------------------------------
@@ -1805,6 +1861,7 @@
Address 0x........ is 52 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 53 ----------
---Thread-Announcement------------------------------------------
@@ -1839,6 +1896,7 @@
Address 0x........ is 53 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 54 ----------
---Thread-Announcement------------------------------------------
@@ -1873,6 +1931,7 @@
Address 0x........ is 54 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 55 ----------
---Thread-Announcement------------------------------------------
@@ -1907,6 +1966,7 @@
Address 0x........ is 55 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 56 ----------
---Thread-Announcement------------------------------------------
@@ -1941,6 +2001,7 @@
Address 0x........ is 56 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 57 ----------
---Thread-Announcement------------------------------------------
@@ -1975,6 +2036,7 @@
Address 0x........ is 57 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 58 ----------
---Thread-Announcement------------------------------------------
@@ -2009,6 +2071,7 @@
Address 0x........ is 58 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 59 ----------
---Thread-Announcement------------------------------------------
@@ -2043,6 +2106,7 @@
Address 0x........ is 59 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 60 ----------
---Thread-Announcement------------------------------------------
@@ -2077,6 +2141,7 @@
Address 0x........ is 60 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 61 ----------
---Thread-Announcement------------------------------------------
@@ -2111,6 +2176,7 @@
Address 0x........ is 61 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 62 ----------
---Thread-Announcement------------------------------------------
@@ -2145,6 +2211,7 @@
Address 0x........ is 62 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 63 ----------
---Thread-Announcement------------------------------------------
@@ -2179,6 +2246,7 @@
Address 0x........ is 63 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 64 ----------
---Thread-Announcement------------------------------------------
@@ -2213,6 +2281,7 @@
Address 0x........ is 64 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 65 ----------
---Thread-Announcement------------------------------------------
@@ -2247,6 +2316,7 @@
Address 0x........ is 65 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 66 ----------
---Thread-Announcement------------------------------------------
@@ -2281,6 +2351,7 @@
Address 0x........ is 66 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 67 ----------
---Thread-Announcement------------------------------------------
@@ -2315,6 +2386,7 @@
Address 0x........ is 67 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 68 ----------
---Thread-Announcement------------------------------------------
@@ -2349,6 +2421,7 @@
Address 0x........ is 68 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 69 ----------
---Thread-Announcement------------------------------------------
@@ -2383,6 +2456,7 @@
Address 0x........ is 69 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 70 ----------
---Thread-Announcement------------------------------------------
@@ -2417,6 +2491,7 @@
Address 0x........ is 70 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 71 ----------
---Thread-Announcement------------------------------------------
@@ -2451,6 +2526,7 @@
Address 0x........ is 71 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 72 ----------
---Thread-Announcement------------------------------------------
@@ -2485,6 +2561,7 @@
Address 0x........ is 72 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 73 ----------
---Thread-Announcement------------------------------------------
@@ -2519,6 +2596,7 @@
Address 0x........ is 73 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 74 ----------
---Thread-Announcement------------------------------------------
@@ -2553,6 +2631,7 @@
Address 0x........ is 74 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 75 ----------
---Thread-Announcement------------------------------------------
@@ -2587,6 +2666,7 @@
Address 0x........ is 75 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 76 ----------
---Thread-Announcement------------------------------------------
@@ -2621,6 +2701,7 @@
Address 0x........ is 76 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 77 ----------
---Thread-Announcement------------------------------------------
@@ -2655,6 +2736,7 @@
Address 0x........ is 77 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 78 ----------
---Thread-Announcement------------------------------------------
@@ -2689,6 +2771,7 @@
Address 0x........ is 78 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 79 ----------
---Thread-Announcement------------------------------------------
@@ -2723,6 +2806,7 @@
Address 0x........ is 79 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 80 ----------
---Thread-Announcement------------------------------------------
@@ -2757,6 +2841,7 @@
Address 0x........ is 80 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 81 ----------
---Thread-Announcement------------------------------------------
@@ -2791,6 +2876,7 @@
Address 0x........ is 81 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 82 ----------
---Thread-Announcement------------------------------------------
@@ -2825,6 +2911,7 @@
Address 0x........ is 82 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 83 ----------
---Thread-Announcement------------------------------------------
@@ -2859,6 +2946,7 @@
Address 0x........ is 83 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 84 ----------
---Thread-Announcement------------------------------------------
@@ -2893,6 +2981,7 @@
Address 0x........ is 84 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 85 ----------
---Thread-Announcement------------------------------------------
@@ -2927,6 +3016,7 @@
Address 0x........ is 85 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 86 ----------
---Thread-Announcement------------------------------------------
@@ -2961,6 +3051,7 @@
Address 0x........ is 86 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 87 ----------
---Thread-Announcement------------------------------------------
@@ -2995,6 +3086,7 @@
Address 0x........ is 87 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 88 ----------
---Thread-Announcement------------------------------------------
@@ -3029,6 +3121,7 @@
Address 0x........ is 88 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 89 ----------
---Thread-Announcement------------------------------------------
@@ -3063,6 +3156,7 @@
Address 0x........ is 89 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 90 ----------
---Thread-Announcement------------------------------------------
@@ -3097,6 +3191,7 @@
Address 0x........ is 90 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 91 ----------
---Thread-Announcement------------------------------------------
@@ -3131,6 +3226,7 @@
Address 0x........ is 91 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 92 ----------
---Thread-Announcement------------------------------------------
@@ -3165,6 +3261,7 @@
Address 0x........ is 92 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 93 ----------
---Thread-Announcement------------------------------------------
@@ -3199,6 +3296,7 @@
Address 0x........ is 93 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 94 ----------
---Thread-Announcement------------------------------------------
@@ -3233,6 +3331,7 @@
Address 0x........ is 94 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 95 ----------
---Thread-Announcement------------------------------------------
@@ -3267,6 +3366,7 @@
Address 0x........ is 95 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 96 ----------
---Thread-Announcement------------------------------------------
@@ -3301,6 +3401,7 @@
Address 0x........ is 96 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 97 ----------
---Thread-Announcement------------------------------------------
@@ -3335,6 +3436,7 @@
Address 0x........ is 97 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- char gran, 0 .. 99, skip 98 ----------
---Thread-Announcement------------------------------------------
@@ -3369,6 +3471,7 @@
Address 0x........ is 98 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
==========================================================
@@ -3408,6 +3511,7 @@
Address 0x........ is 0 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
More than 100 errors detected. Subsequent errors
@@ -3445,6 +3549,7 @@
Address 0x........ is 1 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -3464,6 +3569,7 @@
Address 0x........ is 2 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- short gran, 0 .. 98, skip 2 ----------
---Thread-Announcement------------------------------------------
@@ -3498,6 +3604,7 @@
Address 0x........ is 2 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- short gran, 1 .. 98, skip 3 ----------
---Thread-Announcement------------------------------------------
@@ -3532,6 +3639,7 @@
Address 0x........ is 3 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -3551,6 +3659,7 @@
Address 0x........ is 4 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- short gran, 0 .. 98, skip 4 ----------
---Thread-Announcement------------------------------------------
@@ -3585,6 +3694,7 @@
Address 0x........ is 4 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- short gran, 1 .. 98, skip 5 ----------
---Thread-Announcement------------------------------------------
@@ -3619,6 +3729,7 @@
Address 0x........ is 5 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -3638,6 +3749,7 @@
Address 0x........ is 6 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- short gran, 0 .. 98, skip 6 ----------
---Thread-Announcement------------------------------------------
@@ -3672,6 +3784,7 @@
Address 0x........ is 6 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- short gran, 1 .. 98, skip 7 ----------
---Thread-Announcement------------------------------------------
@@ -3706,6 +3819,7 @@
Address 0x........ is 7 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
----------------------------------------------------------------
@@ -3725,6 +3839,7 @@
Address 0x........ is 8 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- short gran, 0 .. 98, skip 8 ----------
---Thread-Announcement------------------------------------------
@@ -3759,6 +3874,7 @@
Address 0x........ is 8 bytes inside a block of size 100 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
by 0x........: main (tc19_shadowmem.c:144)
+ Block was alloc'd by thread #x
---------- short gran, 1 .. 98, skip 9 ----------
---Thread-Announcement------------------------------------------
@@ -3793,6 +3909,7 @@
Address 0x........ is 9 bytes inside a block of size 100 alloc'd
...
[truncated message content] |
--- trunk/helgrind/hg_addrdescr.c (original)
+++ trunk/helgrind/hg_addrdescr.c Fri Jul 18 00:03:58 2014
@@ -32,6 +32,7 @@
#include "pub_tool_libcbase.h"
#include "pub_tool_libcprint.h"
#include "pub_tool_libcassert.h"
+#include "pub_tool_wordfm.h"
#include "pub_tool_xarray.h"
#include "pub_tool_execontext.h"
#include "pub_tool_debuginfo.h"
@@ -39,14 +40,17 @@
#include "pub_tool_addrinfo.h"
#include "hg_basics.h"
+#include "hg_wordset.h"
+#include "hg_lock_n_thread.h"
#include "hg_addrdescr.h" /* self */
void HG_(describe_addr) ( Addr a, /*OUT*/AddrInfo* ai )
{
tl_assert(ai->tag == Addr_Undescribed);
/* hctxt/haddr/hszB describe the addr if it is a heap block. */
ExeContext* hctxt;
+ UInt tnr;
Addr haddr;
SizeT hszB;
@@ -58,6 +62,7 @@
Bool is_heapblock
= HG_(mm_find_containing_block)(
&hctxt,
+ &tnr,
&haddr,
&hszB,
a
@@ -70,10 +75,27 @@
ai->Addr.Block.block_szB = hszB;
ai->Addr.Block.rwoffset = (Word)(a) - (Word)(haddr);
ai->Addr.Block.allocated_at = hctxt;
+ VG_(initThreadInfo) (&ai->Addr.Block.alloc_tinfo);
+ ai->Addr.Block.alloc_tinfo.tnr = tnr;
ai->Addr.Block.freed_at = VG_(null_ExeContext)();;
} else {
/* No block found. Search a non-heap block description. */
VG_(describe_addr) (a, ai);
+
+ /* In case ai contains a tid, set tnr to the corresponding helgrind
+ thread number. */
+ if (ai->tag == Addr_Stack) {
+ Thread* thr = get_admin_threads();
+
+ tl_assert(ai->Addr.Stack.tinfo.tid);
+ while (thr) {
+ if (thr->coretid == ai->Addr.Stack.tinfo.tid) {
+ ai->Addr.Stack.tinfo.tnr = thr->errmsg_index;
+ break;
+ }
+ thr = thr->admin;
+ }
+ }
}
}
Modified: trunk/helgrind/hg_addrdescr.h
@@ -39,14 +40,17 @@
{
tl_assert(ai->tag == Addr_Undescribed);
- /* hctxt/haddr/hszB describe the addr if it is a heap block. */
+ /* hctxt/tnr/haddr/hszB describe the addr if it is a heap block. */
ExeContext* hctxt;
==============================================================================